@@ -2,6 +2,8 @@ mod bytevis;
 mod common;
 mod eventloop;
 mod handlers;
+mod navigation;
+pub mod tree_view;
 
 pub use bytevis::*;
 pub use common::*;
